import 'dart:convert';

import 'package:dart_cure/security/cryptography.dart';
import 'package:test/test.dart';

void main() {
  test('CRC.crc4ITU()', () {
    final crc = CRC.crc4ITU();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x07;
    expect(actual, matcher);
  });

  test('CRC.crc4ITU() - MAPPING', () {
    final crc = CRC.crc4ITU(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x07;
    expect(actual, matcher);
  });

  test('CRC.crc5EPC()', () {
    final crc = CRC.crc5EPC();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x00;
    expect(actual, matcher);
  });

  test('CRC.crc5EPC() - MAPPING', () {
    final crc = CRC.crc5EPC(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x00;
    expect(actual, matcher);
  });

  test('CRC.crc5ITU()', () {
    final crc = CRC.crc5ITU();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x07;
    expect(actual, matcher);
  });

  test('CRC.crc5ITU() - MAPPING', () {
    final crc = CRC.crc5ITU(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x07;
    expect(actual, matcher);
  });

  test('CRC.crc5USB()', () {
    final crc = CRC.crc5USB();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x19;
    expect(actual, matcher);
  });

  test('CRC.crc5USB() - MAPPING', () {
    final crc = CRC.crc5USB(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x19;
    expect(actual, matcher);
  });

  test('CRC.crc6ITU()', () {
    final crc = CRC.crc6ITU();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x06;
    expect(actual, matcher);
  });

  test('CRC.crc6ITU() - MAPPING', () {
    final crc = CRC.crc6ITU(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x06;
    expect(actual, matcher);
  });

  test('CRC.crc7MMC()', () {
    final crc = CRC.crc7MMC();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x75;
    expect(actual, matcher);
  });

  test('CRC.crc7MMC() - MAPPING', () {
    final crc = CRC.crc7MMC(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x75;
    expect(actual, matcher);
  });

  test('CRC.crc8()', () {
    final crc = CRC.crc8();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xF4;
    expect(actual, matcher);
  });

  test('CRC.crc8() - MAPPING', () {
    final crc = CRC.crc8(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xF4;
    expect(actual, matcher);
  });

  test('CRC.crc8ITU()', () {
    final crc = CRC.crc8ITU();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xA1;
    expect(actual, matcher);
  });

  test('CRC.crc8ITU() - MAPPING', () {
    final crc = CRC.crc8ITU(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xA1;
    expect(actual, matcher);
  });

  test('CRC.crc8MAXIM()', () {
    final crc = CRC.crc8MAXIM();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xA1;
    expect(actual, matcher);
  });

  test('CRC.crc8MAXIM() - MAPPING', () {
    final crc = CRC.crc8MAXIM(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xA1;
    expect(actual, matcher);
  });

  test('CRC.crc8ROHC()', () {
    final crc = CRC.crc8ROHC();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xD0;
    expect(actual, matcher);
  });

  test('CRC.crc8ROHC() - MAPPING', () {
    final crc = CRC.crc8ROHC(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xD0;
    expect(actual, matcher);
  });

  test('CRC.crc16()', () {
    final crc = CRC.crc16();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xBB3D;
    expect(actual, matcher);
  });

  test('CRC.crc16() - MAPPING', () {
    final crc = CRC.crc16(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xBB3D;
    expect(actual, matcher);
  });

  test('CRC.crc16CCITT()', () {
    final crc = CRC.crc16CCITT();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x2189;
    expect(actual, matcher);
  });

  test('CRC.crc16CCITT() - MAPPING', () {
    final crc = CRC.crc16CCITT(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x2189;
    expect(actual, matcher);
  });

  test('CRC.crc16CCITTFALSE()', () {
    final crc = CRC.crc16CCITTFALSE();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x29B1;
    expect(actual, matcher);
  });

  test('CRC.crc16CCITTFALSE() - MAPPING', () {
    final crc = CRC.crc16CCITTFALSE(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x29B1;
    expect(actual, matcher);
  });

  test('CRC.crc16DNP()', () {
    final crc = CRC.crc16DNP();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xEA82;
    expect(actual, matcher);
  });

  test('CRC.crc16DNP() - MAPPING', () {
    final crc = CRC.crc16DNP(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xEA82;
    expect(actual, matcher);
  });

  test('CRC.crc16MAXIM()', () {
    final crc = CRC.crc16MAXIM();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x44C2;
    expect(actual, matcher);
  });

  test('CRC.crc16MAXIM() - MAPPING', () {
    final crc = CRC.crc16MAXIM(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x44C2;
    expect(actual, matcher);
  });

  test('CRC.crc16MODBUS()', () {
    final crc = CRC.crc16MODBUS();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x4B37;
    expect(actual, matcher);
  });

  test('CRC.crc16MODBUS() - MAPPING', () {
    final crc = CRC.crc16MODBUS(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x4B37;
    expect(actual, matcher);
  });

  test('CRC.crc16USB()', () {
    final crc = CRC.crc16USB();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xB4C8;
    expect(actual, matcher);
  });

  test('CRC.crc16USB() - MAPPING', () {
    final crc = CRC.crc16USB(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xB4C8;
    expect(actual, matcher);
  });

  test('CRC.crc16X25()', () {
    final crc = CRC.crc16X25();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x906E;
    expect(actual, matcher);
  });

  test('CRC.crc16X25() - MAPPING', () {
    final crc = CRC.crc16X25(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x906E;
    expect(actual, matcher);
  });

  test('CRC.crc16XMODEM()', () {
    final crc = CRC.crc16XMODEM();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x31C3;
    expect(actual, matcher);
  });

  test('CRC.crc16XMODEM() - MAPPING', () {
    final crc = CRC.crc16XMODEM(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x31C3;
    expect(actual, matcher);
  });

  test('CRC.crc32()', () {
    final crc = CRC.crc32();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xCBF43926;
    expect(actual, matcher);
  });

  test('CRC.crc32() - MAPPING', () {
    final crc = CRC.crc32(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0xCBF43926;
    expect(actual, matcher);
  });

  test('CRC.crc32MPEG2()', () {
    final crc = CRC.crc32MPEG2();
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x0376E6E7;
    expect(actual, matcher);
  });

  test('CRC.crc32MPEG2() - MAPPING', () {
    final crc = CRC.crc32MPEG2(mapping: true);
    final data = utf8.encode('123456789');
    final actual = crc.calculate(data);
    final matcher = 0x0376E6E7;
    expect(actual, matcher);
  });

  test('CRC.verify()', () {
    final crc = CRC.crc4ITU();
    final data = utf8.encode('ABCDEFGHIJKLMNOPQRSTUVWXYZ');
    final actual = crc.verify(data, 0x0B);
    final matcher = true;
    expect(actual, matcher);
  });
}
